#!/usr/bin/perl

use strict;
use warnings;

use CGI;
use XML::Simple;
use HTML::Template;

# Initialize
my $xml = XMLin( "slides.xml", ForceArray => [ "author" ] );
my $temp = HTML::Template->new( filename => 'present.tmpl' );
my $cgi = new CGI;

my $cur = ($cgi->param( 'cur' ) || 1) - 1;

# Create the Table of Contents Slide
unshift( @{ $xml->{slide} }, {
  title => "Table of Contents",
  body => join( '', map{ "<li> " . $_->{title} } @{ $xml->{slide} } )
} );

# Create the Title Slide (Where applicable)
if ( $xml->{title} ) {
  unshift( @{ $xml->{slide} }, { 
    title => $xml->{title},
    authors => ( $xml->{authors} ? $xml->{authors}{author} : [] )
  } );
}

# Load the data into the template, for the current slide
my $data = $xml->{slide}->[$cur];

$data->{num} = $cur + 1;
$data->{max} = @{ $xml->{slide} };

foreach ( keys %{ $data } ) {
  $data->{$_} = 0 if ( ref( $data->{$_} ) eq 'HASH' );
  $temp->param( $_ => $data->{$_} );
}

# Figure out the previous slide
if ( $cur > 0 ) {
  my %data = ( num => $cur, title => $xml->{slide}->[$cur - 1]->{title} );
  $temp->param( prev => [ \%data ] );
}

# Figure out the next slide
if ( @{ $xml->{slide} } > $cur + 1 ) {
  my %data = ( num => $cur + 2, title => $xml->{slide}->[$cur + 1]->{title} );
  $temp->param( next => [ \%data ] );
}

# Print out the slide
print "Content-type: text/html\n\n";
print $temp->output;
